﻿//===========================================================================
// MPI_AutoWaitForPicture.js
//===========================================================================

/*:
 * @plugindesc ピクチャの表示実行時、画像読み込み完了まで自動でウェイトする機能を提供します。
 * @author 奏ねこま（おとぶき ねこま）
 *
 * @param ピクチャの表示自動ウェイト切替スイッチ
 * @desc ピクチャの表示実行時の自動ウェイトのON/OFFを切り替えるスイッチの番号を指定してください。
 * @default 0
 *
 * @help
 * [ 概要 ] ...
 *  イベントコマンド「ピクチャの表示」実行時、画像読み込みが完了するまでウェイト
 *  状態（イベントが進まないよう）にします。
 *
 * [ 動作説明 ] ...
 *  イベントコマンド「ピクチャの表示」実行時、デフォルトでは、表示しようとしてい
 *  る画像が完全に読み込まるのを待たずに、イベントが先に進んでしまいます。
 *  本プラグインを導入すると、表示しようとしている画像が完全に読み込まれるまで、
 *  イベントをウェイト状態にして先に進まないようにします。
 *
 * [ プラグインパラメータ ] ...
 *  ・ピクチャの表示自動ウェイト切替スイッチ
 *    このパラメータに指定した番号のスイッチが、ピクチャの表示実行時の自動ウェイ
 *    トを切り替えるスイッチになります。指定のスイッチがONの間、ピクチャの表示実
 *    行時に、自動ウェイトを行いません。
 *
 * [ プラグインコマンド ] ...
 *  プラグインコマンドはありません。
 *
 * [ 利用規約 ] ................................................................
 *  ・本プラグインの利用は、RPGツクールMV/RPGMakerMVの正規ユーザーに限られます。
 *  ・商用、非商用、有償、無償、一般向け、成人向けを問わず、利用可能です。
 *  ・利用の際、連絡や報告は必要ありません。また、製作者名の記載等も不要です。
 *  ・プラグインを導入した作品に同梱する形以外での再配布、転載はご遠慮ください。
 *  ・不具合対応以外のサポートやリクエストは、基本的に受け付けておりません。
 *  ・本プラグインにより生じたいかなる問題についても、一切の責任を負いかねます。
 * [ 改訂履歴 ] ................................................................
 *   Version 1.00  2016/11/25  First edition.
 * -+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-
 *  Web Site: http://makonet.sakura.ne.jp/rpg_tkool/
 *  Twitter : https://twitter.com/koma_neko
 *  Copylight (c) 2016 Nekoma Otobuki
 */

var Imported = Imported || {};
Imported.MPI_AutoWaitForPicture = true;

var Makonet = Makonet || {};
Makonet.AWP = {};

(function () {
  "use strict";

  var AWP = Makonet.AWP;
  AWP.product = "MPI_AutoWaitForPicture";
  AWP.parameters = PluginManager.parameters(AWP.product);
  AWP.switchId = +AWP.parameters["ピクチャの表示自動ウェイト切替スイッチ"];

  //==============================================================================
  // Game_Interpreter
  //==============================================================================

  (function (o, p) {
    var f = o[p];
    o[p] = function () {
      var wait = !(AWP.switchId && $gameSwitches.value(AWP.switchId));
      if (wait) {
        this.wait(1);
        this.setWaitMode("image");
      }
      return f.apply(this, arguments);
    };
  })(Game_Interpreter.prototype, "command231");
})();
